@@ -23,7 +23,7 @@ def run_ml_cli_pipeline(args, config_path, ml_cli_template_path):
     with open(config_path) as config_file:
         config = json.load(config_file)
 
-    if datasets_configuration_json == "" or datasets_configuration_json is None:
+    if datasets_configuration_json != "" and datasets_configuration_json is not None:
         config["datasets"] = json.loads(datasets_configuration_json)
 
     if mlcli_template_json is None or mlcli_template_json == "":
@@ -37,15 +37,8 @@ def run_ml_cli_pipeline(args, config_path, ml_cli_template_path):
 def run_ml_cli_pipeline_from(config, config_aml_path, mlcli_template, build_id="", build_tags={}, skip_train_execution=False):
     # Experiment
     experiment_name = config["experiment_name"]
-
-    # #################### ENVIRONMENT CREATION #####################
-    # Load the workspace
     workspace = load_workspace(config_aml_path)
-
-    # Load a datastore
     datastore = get_datastore(workspace, config["datastore_name"])
-
-    # Create or get compute clusters
     cfg_cluster_cpu = config["cluster"]["cluster_cpu"]
     cluster_cpu = create_cluster(
         workspace,
@@ -57,8 +50,6 @@ def run_ml_cli_pipeline_from(config, config_aml_path, mlcli_template, build_id="
         subnet_name=cfg_cluster_cpu["subnet_name"],
     )
     clusters = [cluster_cpu]
-
-    # Create and register Python environments for the experiment
     cfg_light_env = config["environment"]["light_env"]
     light_env = create_environment(
         workspace,
@@ -75,39 +66,28 @@ def run_ml_cli_pipeline_from(config, config_aml_path, mlcli_template, build_id="
         dockerfile=cfg_ml_cli_env["dockerfile"]
     )
     environments = [light_env, ml_cli_env]
-
     dataset_dict = config["datasets"]
-
-    # #################### PIPELINE CREATION AND SUBMISSION #####################
-
-    # Create the pipeline
     pipeline = train_pipeline(
         workspace, datastore, clusters, environments, dataset_dict, mlcli_template
     )
-
     if skip_train_execution is False:
         experiment = Experiment(workspace=workspace, name=experiment_name)
-
-        # Run the pipeline
         pipeline_run = experiment.submit(
             pipeline, regenerate_outputs=False, tags=build_tags
         )
         print("Pipeline submitted for execution.", pipeline_run.id)
     else:
         pipeline.validate()
-
         published_pipeline = pipeline.publish(
             name=experiment_name,
             description="Model training/retraining pipeline",
             version=build_id,
         )
-
         build_data = {
             "pipeline_id": published_pipeline.id,
             "experiment_name": experiment_name,
             "model_name": "",
         }
-
         print(f"Published pipeline name: {published_pipeline.name}")
         print(f"Published pipeline id: {published_pipeline.id}")
         print(f"for build {published_pipeline.version}")
